# zabel-fabric

## Overview

This is part of the Zabel platform.  The **zabel.fabric** package define
_fabrics_.

A fabric is what host a Zabel platform.

**Please note that this library is not feature-complete yet.**

## License

```text
Copyright (c) 2019-2020 Martin Lafaix (martin.lafaix@external.engie.com) and others

This program and the accompanying materials are made
available under the terms of the Eclipse Public License 2.0
which is available at https://www.eclipse.org/legal/epl-2.0/

SPDX-License-Identifier: EPL-2.0
```
